@@ -1,4 +1,4 @@
-from fastapi import FastAPI, Security
+from fastapi import Depends, FastAPI
 from fastapi.security import OAuth2PasswordBearer
 
 app = FastAPI()
@@ -7,5 +7,5 @@ oauth2_scheme = OAuth2PasswordBearer(tokenUrl="/token")
 
 
 @app.get("/items/")
-async def read_items(token: str = Security(oauth2_scheme)):
+async def read_items(token: str = Depends(oauth2_scheme)):
     return {"token": token}
