@@ -1,8 +1,7 @@
 import asyncio
 import inspect
 import logging
-import re
-from typing import Any, Callable, Dict, List, Optional, Set, Type, Union
+from typing import Any, Callable, Dict, List, Optional, Sequence, Set, Type, Union
 
 from fastapi import params
 from fastapi.dependencies.models import Dependant
@@ -14,6 +13,7 @@ from fastapi.dependencies.utils import (
 )
 from fastapi.encoders import jsonable_encoder
 from fastapi.exceptions import RequestValidationError, WebSocketRequestValidationError
+from fastapi.utils import create_cloned_field
 from pydantic import BaseConfig, BaseModel, Schema
 from pydantic.error_wrappers import ErrorWrapper, ValidationError
 from pydantic.fields import Field
@@ -43,17 +43,9 @@ def serialize_response(
     by_alias: bool = True,
     skip_defaults: bool = False,
 ) -> Any:
-
-    encoded = jsonable_encoder(
-        response,
-        include=include,
-        exclude=exclude,
-        by_alias=by_alias,
-        skip_defaults=skip_defaults,
-    )
     if field:
         errors = []
-        value, errors_ = field.validate(encoded, {}, loc=("response",))
+        value, errors_ = field.validate(response, {}, loc=("response",))
         if isinstance(errors_, ErrorWrapper):
             errors.append(errors_)
         elif isinstance(errors_, list):
@@ -68,7 +60,7 @@ def serialize_response(
             skip_defaults=skip_defaults,
         )
     else:
-        return encoded
+        return jsonable_encoder(response)
 
 
 def get_app(
@@ -180,8 +172,6 @@ class APIWebSocketRoute(routing.WebSocketRoute):
                 dependency_overrides_provider=dependency_overrides_provider,
             )
         )
-        regex = "^" + path + "$"
-        regex = re.sub("{([a-zA-Z_][a-zA-Z0-9_]*)}", r"(?P<\1>[^/]+)", regex)
         self.path_regex, self.path_format, self.param_convertors = compile_path(path)
 
 
@@ -194,14 +184,14 @@ class APIRoute(routing.Route):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
         responses: Dict[Union[int, str], Dict[str, Any]] = None,
         deprecated: bool = None,
         name: str = None,
-        methods: List[str] = None,
+        methods: Optional[Union[Set[str], List[str]]] = None,
         operation_id: str = None,
         response_model_include: Set[str] = None,
         response_model_exclude: Set[str] = set(),
@@ -230,11 +220,25 @@ class APIRoute(routing.Route):
                 model_config=BaseConfig,
                 schema=Schema(None),
             )
+            # Create a clone of the field, so that a Pydantic submodel is not returned
+            # as is just because it's an instance of a subclass of a more limited class
+            # e.g. UserInDB (containing hashed_password) could be a subclass of User
+            # that doesn't have the hashed_password. But because it's a subclass, it
+            # would pass the validation and be returned as is.
+            # By being a new field, no inheritance will be passed as is. A new model
+            # will be always created.
+            self.secure_cloned_response_field: Optional[Field] = create_cloned_field(
+                self.response_field
+            )
         else:
             self.response_field = None
+            self.secure_cloned_response_field = None
         self.status_code = status_code
         self.tags = tags or []
-        self.dependencies = dependencies or []
+        if dependencies:
+            self.dependencies = list(dependencies)
+        else:
+            self.dependencies = []
         self.summary = summary
         self.description = description or inspect.cleandoc(self.endpoint.__doc__ or "")
         self.response_description = response_description
@@ -265,7 +269,7 @@ class APIRoute(routing.Route):
         self.deprecated = deprecated
         if methods is None:
             methods = ["GET"]
-        self.methods = methods
+        self.methods = set([method.upper() for method in methods])
         self.operation_id = operation_id
         self.response_model_include = response_model_include
         self.response_model_exclude = response_model_exclude
@@ -292,7 +296,7 @@ class APIRoute(routing.Route):
                 body_field=self.body_field,
                 status_code=self.status_code,
                 response_class=self.response_class,
-                response_field=self.response_field,
+                response_field=self.secure_cloned_response_field,
                 response_model_include=self.response_model_include,
                 response_model_exclude=self.response_model_exclude,
                 response_model_by_alias=self.response_model_by_alias,
@@ -323,13 +327,13 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
         responses: Dict[Union[int, str], Dict[str, Any]] = None,
         deprecated: bool = None,
-        methods: List[str] = None,
+        methods: Optional[Union[Set[str], List[str]]] = None,
         operation_id: str = None,
         response_model_include: Set[str] = None,
         response_model_exclude: Set[str] = set(),
@@ -345,7 +349,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -371,7 +375,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -394,7 +398,7 @@ class APIRouter(routing.Router):
                 response_model=response_model,
                 status_code=status_code,
                 tags=tags or [],
-                dependencies=dependencies or [],
+                dependencies=dependencies,
                 summary=summary,
                 description=description,
                 response_description=response_description,
@@ -433,7 +437,7 @@ class APIRouter(routing.Router):
         *,
         prefix: str = "",
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         responses: Dict[Union[int, str], Dict[str, Any]] = None,
     ) -> None:
         if prefix:
@@ -452,7 +456,8 @@ class APIRouter(routing.Router):
                     response_model=route.response_model,
                     status_code=route.status_code,
                     tags=(route.tags or []) + (tags or []),
-                    dependencies=(dependencies or []) + (route.dependencies or []),
+                    dependencies=list(dependencies or [])
+                    + list(route.dependencies or []),
                     summary=route.summary,
                     description=route.description,
                     response_description=route.response_description,
@@ -472,7 +477,7 @@ class APIRouter(routing.Router):
                 self.add_route(
                     prefix + route.path,
                     route.endpoint,
-                    methods=route.methods,
+                    methods=list(route.methods or []),
                     include_in_schema=route.include_in_schema,
                     name=route.name,
                 )
@@ -492,7 +497,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -513,7 +518,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -537,7 +542,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -557,7 +562,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -581,7 +586,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -601,7 +606,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -625,7 +630,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -645,7 +650,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -669,7 +674,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -689,7 +694,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -713,7 +718,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -733,7 +738,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -757,7 +762,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -777,7 +782,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
@@ -801,7 +806,7 @@ class APIRouter(routing.Router):
         response_model: Type[Any] = None,
         status_code: int = 200,
         tags: List[str] = None,
-        dependencies: List[params.Depends] = None,
+        dependencies: Sequence[params.Depends] = None,
         summary: str = None,
         description: str = None,
         response_description: str = "Successful Response",
@@ -821,7 +826,7 @@ class APIRouter(routing.Router):
             response_model=response_model,
             status_code=status_code,
             tags=tags or [],
-            dependencies=dependencies or [],
+            dependencies=dependencies,
             summary=summary,
             description=description,
             response_description=response_description,
